@@ -1,14 +1,16 @@
 context("lookup_statuses")
 
 test_that("lookup_statuses returns users data", {
-	skip_on_cran()
+  skip_on_cran()
 
-	n <- 3
-	token <- readRDS("twitter_tokens")
-	x <- lookup_statuses(c("558115838503690243",
-		"760182486005583872", "776053079540166657"), token = token)
+  n <- 3
+  token <- readRDS("twitter_tokens")
+  x <- lookup_statuses(c("558115838503690243",
+                         "760182486005583872",
+                         "776053079540166657"),
+                       token = token)
 
-	expect_equal(is.data.frame(x), TRUE)
+  expect_equal(is.data.frame(x), TRUE)
   expect_named(x)
   expect_true("status_id" %in% names(x))
   expect_equal(nrow(x), n)
