@@ -5,7 +5,8 @@ test_that("lookup_users returns users data", {
 
   n <- 4
   token <- readRDS("twitter_tokens")
-  x <- lookup_users(c("cnn", "potus", "twitter", "kearneymw"), token = token)
+  x <- lookup_users(c("cnn", "potus", "twitter", "kearneymw"),
+                    token = token)
 
   expect_equal(is.data.frame(x), TRUE)
   expect_named(x)
