@@ -3,13 +3,21 @@ context("system_token")
 test_that("system_token functions", {
   skip_on_cran()
 
-  x <- search_tweets("a OR b OR c OR d OR e",
-  	max_id = NULL, type = "recent", include_rts = TRUE)
+  x <- search_tweets(
+    "a OR b OR c OR d OR e",
+    max_id = NULL,
+    type = "recent",
+    include_rts = TRUE
+  )
 
   tokens <- get_tokens()
-  x <- search_tweets("a OR b OR c OR d OR e", token = tokens,
-    max_id = NULL, type = "recent", include_rts = FALSE)
-
+  x <- search_tweets(
+    "a OR b OR c OR d OR e",
+    token = tokens,
+    max_id = NULL,
+    type = "recent",
+    include_rts = FALSE
+  )
   expect_equal(is.data.frame(x), TRUE)
   expect_named(x)
   expect_true("status_id" %in% names(x))
@@ -22,7 +30,7 @@ test_that("system_token functions", {
   expect_gt(ncol(users_data(x)), 15)
   expect_named(users_data(x))
 
-  expect_error(search_tweets(verbose = FALSE, token = tokens))
+  expect_error(search_tweets(c(1:10), verbose = FALSE, token = tokens))
   expect_error(search_tweets("tweet", token = "token"))
   expect_error(search_tweets("stats", type = "all", token = tokens))
 })
